# lingo - payment and billing system
# Copyright (C) 2022  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.urls import path

from . import views

urlpatterns = [
    path(
        'agenda/<slug:agenda_identifier>/check-types/',
        views.agenda_check_type_list,
        name='api-agenda-check-types',
    ),
    path(
        'pricing/compute/',
        views.pricing_compute,
        name='api-pricing-compute',
    ),
    path(
        'regies/',
        views.invoicing_regies,
        name='api-invoicing-regies',
    ),
    path(
        'regie/<slug:regie_identifier>/payment-types/',
        views.invoicing_payment_types,
        name='api-invoicing-payment-types',
    ),
    path(
        'regie/<slug:regie_identifier>/invoices/',
        views.invoicing_invoices,
        name='api-invoicing-invoices',
    ),
    path(
        'regie/<slug:regie_identifier>/invoices/history/',
        views.invoicing_history_invoices,
        name='api-invoicing-history-invoices',
    ),
    path(
        'regie/<slug:regie_identifier>/invoice/<uuid:invoice_identifier>/',
        views.invoicing_invoice,
        name='api-invoicing-invoice',
    ),
    path(
        'regie/<slug:regie_identifier>/invoice/<uuid:invoice_identifier>/pdf/',
        views.invoicing_invoice_pdf,
        name='api-invoicing-invoice-pdf',
    ),
    path(
        'regie/<slug:regie_identifier>/invoice/<uuid:invoice_identifier>/payments/pdf/',
        views.invoicing_invoice_payments_pdf,
        name='api-invoicing-invoice-payments-pdf',
    ),
    path(
        'regie/<slug:regie_identifier>/invoice/<uuid:invoice_identifier>/pay/',
        views.invoicing_invoice_pay,
        name='api-invoicing-invoice-pay',
    ),
    path(
        'regie/<slug:regie_identifier>/draft-invoices/',
        views.invoicing_draft_invoices,
        name='api-invoicing-draft-invoices',
    ),
    path(
        'regie/<slug:regie_identifier>/draft-invoice/<uuid:invoice_identifier>/lines/',
        views.invoicing_draft_invoice_lines,
        name='api-invoicing-draft-invoice-lines',
    ),
    path(
        'regie/<slug:regie_identifier>/draft-invoice/<uuid:invoice_identifier>/close/',
        views.invoicing_draft_invoice_close,
        name='api-invoicing-draft-invoice-close',
    ),
    path(
        'regie/<slug:regie_identifier>/injected-lines/',
        views.injected_lines,
        name='api-invoicing-injected-lines',
    ),
    path(
        'regie/<slug:regie_identifier>/payments/',
        views.invoicing_payments,
        name='api-invoicing-payments',
    ),
    path(
        'regie/<slug:regie_identifier>/payment/<uuid:payment_identifier>/pdf/',
        views.invoicing_payment_pdf,
        name='api-invoicing-payment-pdf',
    ),
]
